Index: uspace/drv/uhci-hcd/batch.c
===================================================================
--- uspace/drv/uhci-hcd/batch.c	(revision 87644b475e40058a32e8bf51a05dc7c729e2321d)
+++ uspace/drv/uhci-hcd/batch.c	(revision e18e0d67759e614c32642ec217525906007f52db)
@@ -48,5 +48,5 @@
 	qh_t *qh;
 	td_t *tds;
-	size_t packets;
+	size_t transfers;
 	usb_device_keeper_t *manager;
 } uhci_batch_t;
@@ -64,5 +64,5 @@
  * @param[in] target Device and endpoint target of the transaction.
  * @param[in] transfer_type Interrupt, Control or Bulk.
  * @param[in] max_packet_size maximum allowed size of data packets.
  * @param[in] speed Speed of the transaction.
  * @param[in] buffer Data source/destination.
@@ -77,5 +77,5 @@
  * NULL otherwise.
  *
  * Determines the number of needed packets (TDs). Prepares a transport buffer
  * (that is accessible by the hardware). Initializes parameters needed for the
  * transaction and callback.
@@ -117,13 +117,13 @@
 	instance->private_data = data;
 
-	data->packets = (buffer_size + max_packet_size - 1) / max_packet_size;
+	data->transfers = (buffer_size + max_packet_size - 1) / max_packet_size;
 	if (transfer_type == USB_TRANSFER_CONTROL) {
-		data->packets += 2;
-	}
-
-	data->tds = malloc32(sizeof(td_t) * data->packets);
+		data->transfers += 2;
+	}
+
+	data->tds = malloc32(sizeof(td_t) * data->transfers);
 	CHECK_NULL_DISPOSE_RETURN(
 	    data->tds, "Failed to allocate transfer descriptors.\n");
-	bzero(data->tds, sizeof(td_t) * data->packets);
+	bzero(data->tds, sizeof(td_t) * data->transfers);
 
 	data->qh = malloc32(sizeof(qh_t));
@@ -166,9 +166,9 @@
 	assert(data);
 
-	usb_log_debug2("Batch(%p) checking %d packet(s) for completion.\n",
-	    instance, data->packets);
+	usb_log_debug2("Batch(%p) checking %d transfer(s) for completion.\n",
+	    instance, data->transfers);
 	instance->transfered_size = 0;
 	size_t i = 0;
-	for (;i < data->packets; ++i) {
+	for (;i < data->transfers; ++i) {
 		if (td_is_active(&data->tds[i])) {
 			return false;
@@ -298,8 +298,8 @@
  *
  * @param[in] instance Batch structure to use.
  * @param[in] pid to use for data packets.
  *
  * Packets with alternating toggle bit and supplied pid value.
  * The last packet is marked with IOC flag.
  */
 void batch_data(usb_transfer_batch_t *instance, usb_packet_id pid)
@@ -314,5 +314,5 @@
 	assert(toggle == 0 || toggle == 1);
 
-	size_t packet = 0;
+	size_t transfer = 0;
 	size_t remain_size = instance->buffer_size;
 	while (remain_size > 0) {
@@ -325,21 +325,21 @@
 		    remain_size : instance->max_packet_size;
 
-		td_t *next_packet = (packet + 1 < data->packets)
-		    ? &data->tds[packet + 1] : NULL;
-
-		assert(packet < data->packets);
+		td_t *next_transfer = (transfer + 1 < data->transfers)
+		    ? &data->tds[transfer + 1] : NULL;
+
+		assert(transfer < data->transfers);
 		assert(packet_size <= remain_size);
 
 		td_init(
-		    &data->tds[packet], DEFAULT_ERROR_COUNT, packet_size,
+		    &data->tds[transfer], DEFAULT_ERROR_COUNT, packet_size,
 		    toggle, false, low_speed, instance->target, pid, trans_data,
-		    next_packet);
+		    next_transfer);
 
 
 		toggle = 1 - toggle;
 		remain_size -= packet_size;
-		++packet;
-	}
-	td_set_ioc(&data->tds[packet - 1]);
+		++transfer;
+	}
+	td_set_ioc(&data->tds[transfer - 1]);
 	usb_device_keeper_set_toggle(data->manager, instance->target,
 	    instance->direction, toggle);
@@ -349,11 +349,11 @@
  *
  * @param[in] instance Batch structure to use.
  * @param[in] data_stage to use for data packets.
  * @param[in] status_stage to use for data packets.
  *
  * Setup stage with toggle 0 and USB_PID_SETUP.
  * Data stage with alternating toggle and pid supplied by parameter.
  * Status stage with toggle 1 and pid supplied by parameter.
  * The last packet is marked with IOC.
  */
 void batch_control(usb_transfer_batch_t *instance,
@@ -363,5 +363,5 @@
 	uhci_batch_t *data = instance->private_data;
 	assert(data);
-	assert(data->packets >= 2);
+	assert(data->transfers >= 2);
 
 	const bool low_speed = instance->speed == USB_SPEED_LOW;
@@ -374,5 +374,5 @@
 
 	/* data stage */
-	size_t packet = 1;
+	size_t transfer = 1;
 	size_t remain_size = instance->buffer_size;
 	while (remain_size > 0) {
@@ -388,10 +388,10 @@
 
 		td_init(
-		    &data->tds[packet], DEFAULT_ERROR_COUNT, packet_size,
+		    &data->tds[transfer], DEFAULT_ERROR_COUNT, packet_size,
 		    toggle, false, low_speed, instance->target, data_stage,
-		    control_data, &data->tds[packet + 1]);
-
-		++packet;
-		assert(packet < data->packets);
+		    control_data, &data->tds[transfer + 1]);
+
+		++transfer;
+		assert(transfer < data->transfers);
 		assert(packet_size <= remain_size);
 		remain_size -= packet_size;
@@ -399,13 +399,13 @@
 
 	/* status stage */
-	assert(packet == data->packets - 1);
+	assert(transfer == data->transfers - 1);
 
 	td_init(
-	    &data->tds[packet], DEFAULT_ERROR_COUNT, 0, 1, false, low_speed,
+	    &data->tds[transfer], DEFAULT_ERROR_COUNT, 0, 1, false, low_speed,
 	    instance->target, status_stage, NULL, NULL);
-	td_set_ioc(&data->tds[packet]);
+	td_set_ioc(&data->tds[transfer]);
 
 	usb_log_debug2("Control last TD status: %x.\n",
-	    data->tds[packet].status);
+	    data->tds[transfer].status);
 }
 /*----------------------------------------------------------------------------*/
@@ -64,5 +64,5 @@
  * @param[in] target Device and endpoint target of the transaction.
  * @param[in] transfer_type Interrupt, Control or Bulk.
- * @param[in] max_packet_size maximum allowed size of data packets.
+ * @param[in] max_packet_size maximum allowed size of data transfers.
  * @param[in] speed Speed of the transaction.
  * @param[in] buffer Data source/destination.
@@ -77,5 +77,5 @@
  * NULL otherwise.
  *
- * Determines the number of needed packets (TDs). Prepares a transport buffer
+ * Determines the number of needed transfers (TDs). Prepares a transport buffer
  * (that is accessible by the hardware). Initializes parameters needed for the
  * transaction and callback.
@@ -298,8 +298,8 @@
  *
  * @param[in] instance Batch structure to use.
- * @param[in] pid to use for data packets.
+ * @param[in] pid Pid to use for data transfers.
  *
  * Packets with alternating toggle bit and supplied pid value.
@@ -298,8 +298,8 @@
  *
  * Packets with alternating toggle bit and supplied pid value.
- * The last packet is marked with IOC flag.
+ * The last transfer is marked with IOC flag.
  */
 void batch_data(usb_transfer_batch_t *instance, usb_packet_id pid)
@@ -349,11 +349,11 @@
  *
  * @param[in] instance Batch structure to use.
- * @param[in] data_stage to use for data packets.
- * @param[in] status_stage to use for data packets.
+ * @param[in] data_stage Pid to use for data transfers.
+ * @param[in] status_stage Pid to use for data transfers.
  *
  * Setup stage with toggle 0 and USB_PID_SETUP.
@@ -349,11 +349,11 @@
  * Data stage with alternating toggle and pid supplied by parameter.
  * Status stage with toggle 1 and pid supplied by parameter.
- * The last packet is marked with IOC.
+ * The last transfer is marked with IOC.
  */
 void batch_control(usb_transfer_batch_t *instance,
